pub struct AssetCodeRepository {
pub url: String,
pub contributors: i32,
pub forks: i32,
pub stars: i32,
pub subscribers: i32,
pub open_issues: Option<i32>,
pub closed_issues: i32,
pub open_pull_requests: i32,
pub closed_pull_requests: i32,
}Fields
url: StringThe URL of the code repository used to retrieve social metrics.
contributors: i32The number of contributors to the code repository.
forks: i32The number of forks of the code repository.
stars: i32The number of stars received by the code repository.
subscribers: i32The number of subscribers to the code repository.
open_issues: Option<i32>The number of open issues in the code repository.
closed_issues: i32The number of closed issues in the code repository.
open_pull_requests: i32The number of open pull requests in the code repository.
closed_pull_requests: i32The number of closed pull requests in the code repository.