pub struct AssetDiscordServer {
pub url: Option<String>,
pub name: Option<String>,
pub total_members: Option<i32>,
pub total_closed_pull_requests: Option<i32>,
pub premium_subscribers: Option<i32>,
}Fields
url: Option<String>The URL of the Discord server used to retrieve social metrics.
name: Option<String>The name of the Discord server.
total_members: Option<i32>The total number of users/members in this Discord server.
total_closed_pull_requests: Option<i32>The number of online users in this Discord server.
The number of premium subscribers in this Discord server.