pub struct AssetEvent {
pub type_: String,
pub id: i32,
pub asset_id: i32,
pub event_type: String,
pub announced_on: i64,
pub implementation_start_date: i64,
pub implementation_end_date: Option<i64>,
pub name: String,
pub description: String,
pub created_on: i64,
pub updated_on: Option<i64>,
}Expand description
Asset: Events
Fields
type_: StringType of the message.
id: i32The unique identifier for the asset event entry.
asset_id: i32The unique identifier for the asset the event entry is associated to.
event_type: StringThe event type, one of the following: SECURITY-INCIDENT, HARD-FORK, SOFT-FORK, TICKER-CHANGE, MIGRATION, SUPPLY-BURN, SUPPLY-LOCK, SPLIT, REVERSE-SPLIT, TOKEN-LISTING, TOKEN-DELISTING, NETWORK-CONTROL-CHANGE, OTHER
announced_on: i64The unix timestamp when we were notified of the event.
implementation_start_date: i64The unix timestamp when the event was triggered.
implementation_end_date: Option<i64>The unix timestamp when the event finished.
name: StringName text.
description: StringDescription text.
created_on: i64Asset Event internal creation unix ts in our system.
updated_on: Option<i64>Asset Event internal last updated unix ts in our system.