pub struct AssetReddit {
pub unit: String,
pub timestamp: i64,
pub type_: String,
pub asset_id: i32,
pub asset_symbol: String,
pub total_subscribers: i32,
pub total_active_users: Option<i32>,
pub total_average_posts_per_day: f64,
pub total_average_posts_per_hour: f64,
pub total_average_comments_per_day: f64,
pub total_average_comments_per_hour: f64,
pub subreddits: Option<Vec<AssetSubreddit>>,
}Expand description
Asset: Historical Reddit
Fields
unit: StringThe unit of the historical period update: HOUR for hour and DAY for day.
timestamp: i64The timestamp in seconds of the histo period, for hour it would be start of the hour and for daily it is 00:00 GMT/UTC.
type_: StringThe type of the message.
asset_id: i32The unique identifier for the asset.
asset_symbol: StringInternal mapped symbol for a specific asset.
total_subscribers: i32The number of subscribers to the subreddit.
total_active_users: Option<i32>The number of currently active users in the subreddit.
total_average_posts_per_day: f64The average number of posts per day in the subreddit.
total_average_posts_per_hour: f64The average number of posts per hour in the subreddit.
total_average_comments_per_day: f64The average number of comments per day in the subreddit.
total_average_comments_per_hour: f64The average number of comments per hour in the subreddit.
subreddits: Option<Vec<AssetSubreddit>>An array with all the data for each Subreddit used to calculate the total stats.