pub struct AssetSubreddit {
pub url: Option<String>,
pub name: Option<String>,
pub current_active_users: Option<i32>,
pub average_posts_per_day: Option<f32>,
pub average_posts_per_hour: Option<f32>,
pub average_comments_per_day: Option<f32>,
pub average_comments_per_hour: Option<f32>,
pub subscribers: Option<i32>,
}Fields
url: Option<String>The URL of the Subreddit used to retrieve social metrics.
name: Option<String>The name of the subreddit.
current_active_users: Option<i32>The number of currently active users in the subreddit.
average_posts_per_day: Option<f32>The average number of posts per day in the subreddit.
average_posts_per_hour: Option<f32>The average number of posts per hour in the subreddit.
average_comments_per_day: Option<f32>The average number of comments per day in the subreddit.
average_comments_per_hour: Option<f32>The average number of comments per hour in the subreddit.
subscribers: Option<i32>The number of subscribers to the subreddit.