pub struct AssetTelegram {
pub unit: String,
pub timestamp: i64,
pub type_: String,
pub asset_id: i32,
pub asset_symbol: String,
pub total_members: i32,
pub telegram_groups: Vec<AssetTelegramGroup>,
}Expand description
Asset: Historical Telegram
Fields
unit: StringThe unit of the historical period update: HOUR for hour and DAY for day.
timestamp: i64The timestamp in seconds of the histo period, for hour it would be start of the hour and for daily it is 00:00 GMT/UTC.
type_: StringThe type of the message.
asset_id: i32The unique identifier for the asset.
asset_symbol: StringInternal mapped symbol for a specific asset.
total_members: i32The total number of users/members in this Telegram group.
telegram_groups: Vec<AssetTelegramGroup>An array with all the data for each Telegram group used to calculate the total stats.