pub struct AssetTwitter {
pub unit: String,
pub timestamp: i64,
pub type_: String,
pub asset_id: i32,
pub asset_symbol: String,
pub total_following: i32,
pub total_followers: i32,
pub total_favourites: i32,
pub total_lists: i32,
pub total_statuses: i32,
pub twitter_accounts: Option<Vec<AssetTwitterAccount>>,
}Expand description
Asset: Historical X (Twitter)
Fields
unit: StringThe unit of the historical period update: HOUR for hour and DAY for day.
timestamp: i64The timestamp in seconds of the histo period, for hour it would be start of the hour and for daily it is 00:00 GMT/UTC.
type_: StringThe type of the message.
asset_id: i32The unique identifier for the asset.
asset_symbol: StringInternal mapped symbol for a specific asset.
total_following: i32The total number of accounts followed by this X account.
total_followers: i32The total number of followers of this X account.
total_favourites: i32The total number of tweets favorited by this X account.
total_lists: i32The total number of lists this X account is a member of.
total_statuses: i32The total number of tweets and retweets made by this X account.
twitter_accounts: Option<Vec<AssetTwitterAccount>>An array with all the data for each X account used to calculate the total stats.