pub struct AssetTwitterAccount {
pub url: Option<String>,
pub name: Option<String>,
pub username: Option<String>,
pub verified: Option<bool>,
pub verifyied_type: Option<String>,
pub following: Option<i32>,
pub followers: Option<i32>,
pub favourites: Option<i32>,
pub lists: Option<i32>,
pub statuses: Option<i32>,
}Fields
url: Option<String>The URL of the X account used to retrieve social metrics.
name: Option<String>The name of the X account.
username: Option<String>The username of the X account.
verified: Option<bool>The verification status of the X account.
verifyied_type: Option<String>The verification type of the X account.
following: Option<i32>The number of accounts followed by this X account.
followers: Option<i32>The number of followers of this X account.
favourites: Option<i32>The number of tweets favorited by this X account.
lists: Option<i32>The number of lists this X account is a member of.
statuses: Option<i32>The number of tweets and retweets made by this X account.