pub struct DerIndicesMarkets {
pub type_: String,
pub exchange_status: String,
pub mapped_instrument_total: i64,
pub unmapped_instruments_total: i64,
pub instrument_status: InstrumentStatus,
}Expand description
Derivatives Indices: Markets
Fields
type_: StringType of the message.
exchange_status: StringThe status of the echange. We only poll / stream / connect to the ACTIVE ones, for the RETIRED ones we no longer query for data.
mapped_instrument_total: i64The total number of instruments that have been verified by our mapping team and have been properly assigned with a base, quote, mapping function, and other necessary fields. This is done to ensure that pairs like XXBTZUSD are accurately mapped to BTC-USD and that the pair refers to the correct assets rather than using the same asset id to represent different assets.
unmapped_instruments_total: i64The number of instruments that have not yet been verified by our mapping team.
instrument_status: InstrumentStatusAn object with the total number of instrument for each of the available instrument statuses.