DerIndicesOHLCV

Struct DerIndicesOHLCV 

pub struct DerIndicesOHLCV {
Show 22 fields pub unit: String, pub timestamp: i64, pub type_: String, pub market: String, pub instrument: String, pub open: f64, pub high: f64, pub low: f64, pub close: f64, pub first_message_timestamp: i64, pub last_message_timestamp: i64, pub first_message_value: f64, pub high_message_value: f64, pub high_message_timestamp: i64, pub low_message_value: f64, pub low_message_timestamp: i64, pub last_message_value: f64, pub total_index_updates: i32, pub mapped_instrument: Option<String>, pub currency: Option<String>, pub currency_id: Option<i32>, pub transform_function: Option<String>,
}
Derivatives Indices: Historical OHLCV+

Fields

unit: String

The unit of the historical period update: MINUTE for minute, HOUR for hour and DAY for day.

timestamp: i64

The timestamp in seconds of the histo period, for minute it would be every minute at the beginning of the minute, for hour it would be start of the hour and for daily it is 00:00 GMT/UTC.

type_: String

Type of the message.

market: String

The market / exchange you have requested (name of the market / exchange e.g. bitmex, deribit, ftx, etc.).

instrument: String

The specific financial asset pair that an index is tracking in unmapped format. In most cases this is a combiation of the base and quote assets of the pair.

open: f64

The unmapped instrument ID.

high: f64

The open value for the historical period, this is based on the closest index update before the period start.

low: f64

The max between the open and the highest index update value in this time period (same as open when there no messages in the time period).

close: f64

The min between the open and the lowest index update value in this time period (same as open when there no messages in the time period).

first_message_timestamp: i64

The timestamp in seconds of the first index update in this time period (only available when we have at least one index update in the time period).

last_message_timestamp: i64

The timestamp in seconds of the last index update in this time period (only available when we have at least one index update in the time period).

first_message_value: f64

The open based on the first index update in the time period (only available when we have at least one index update in the time period).

high_message_value: f64

The highest value of the messages in the time period (only available when we have at least one index update in the time period).

high_message_timestamp: i64

The timestamp in seconds of the highest index update in this time period (only available when we have at least one index update in the time period).

low_message_value: f64

The lowest value of the messages in the time period (only available when we have at least one index update in the time period).

low_message_timestamp: i64

The timestamp in seconds of the lowest index update in this time period (only available when we have at least one index update in the time period).

last_message_value: f64

The last index update value in the time period (only available when we have at least one index update in the time period).

total_index_updates: i32

The total number of message updates seen in this time period (0 when there no messages in the time period).

mapped_instrument: Option<String>

The instrument ID, as derived from our mapping rules. Only available on instruments that have been mapped.

currency: Option<String>

The mapped index currency. Only available on instruments that have mapping.

currency_id: Option<i32>

Represents the internal CoinDesk ID for the mapped index currency, e.g. 1. This ID is unique and immutable, ensuring consistent identification.

transform_function: Option<String>

The transform function. This is the function we apply when we do mapping to change values into easier human readable ones and to make sure the mapped direction BASE - QUOTE is constant accross all instruments.