pub struct FuturesInstrumentMetadata {Show 22 fields
pub metadata_version: i32,
pub instrument_status: String,
pub first_seen_on_polling_ts: i64,
pub last_seen_on_polling_ts: i64,
pub instrument: String,
pub instrument_mapping: FuturesInstrumentMapping,
pub instrument_external_data: String,
pub instrument_available_on_instruments_endpoint: bool,
pub index_id: String,
pub index_underlying: String,
pub quote_currency: String,
pub settlement_currency: String,
pub denomination_type: String,
pub contract_currency: String,
pub contract_size: f64,
pub tick_size: f64,
pub delivery_method: String,
pub contract_term: String,
pub contract_creation_ts: i64,
pub contract_expiration_ts: Option<i64>,
pub first_ob_l2_minute_snapshot_t2s: i64,
pub last_ob_l2_minute_snapshot_ts: i64,
}Fields
metadata_version: i32The version of metadata, used for version conversions/migrates.
instrument_status: StringThe status of the instrument, we only poll / stream / connect to the ACTIVE ones, for the RETIRED / IGNORED / EXPIRED / READY_FOR_DECOMMISSIONING means we no longer query/stream data.
first_seen_on_polling_ts: i64This is the first time instrument was seen on instrumentListSourceType POLLING.
last_seen_on_polling_ts: i64This is the last time instrument was seen on instrumentListSourceType POLLING.
instrument: StringThe instrument ID as it is on the exchange with small modifications - we do not allow the following characters inside isntrument ids: ,/&?
instrument_mapping: FuturesInstrumentMappingThe current mapping information for this instrument.
instrument_external_data: StringThe full data we get from the polling endpoint for this specific instrument. his is a JSON stringified object with different properties per exchange.
instrument_available_on_instruments_endpoint: boolThis flags the exchange instrument is currently available on instruments endpoint.
index_id: StringThe id of the index the contract is based on.
index_underlying: StringThe underlying instrument of the index.
quote_currency: StringThe instrument that the contract is priced in.
settlement_currency: StringThe currency used to calculate contract PnL. The settlement currency can be different from the index underlying or quote currencies.
denomination_type: StringVANILLA = (SETTLEMENT_CURRENCY = QUOTE_CURRENCY), INVERSE = (SETTLEMENT_CURRENCY = INDEX_UNDERLYING), QUANTO (SETTLEMENT_CURRENCY != INDEX_UNDERLYING or QUOTE_CURRENCY)
contract_currency: StringThe denomination of the CONTRACT_SIZE.
contract_size: f64The contract size - how much of the contract currency does one contract contain.
tick_size: f64The minimum amount the price can move, denominated in QUOTE_CURRENCY.
delivery_method: StringThe settlement delivery method on the derivative product.
contract_term: StringThe term / duration the contract represents e.g. 3xMONTH.
contract_creation_ts: i64The contract creation timestamp we get for the specific derivative instrument.
contract_expiration_ts: Option<i64>The contract expiration timestamp we get for the specific derivative instrument. Not needed for PERPETUAL contract types.
first_ob_l2_minute_snapshot_t2s: i64Timestamp of the initial Level 2 minute snapshot.
last_ob_l2_minute_snapshot_ts: i64Timestamp of the latest Level 2 minute snapshot.