pub enum NewsSourceID {
Show 83 variants
CoinDesk,
CoinTelegraph,
BitcoinMagazine,
CryptoGlobe,
CoinGape,
Blockworks,
TheDailyHodl,
CryptoSlate,
CryptoPotato,
Decrypt,
CryptoBriefing,
TheBlock,
BitcoinDotCom,
NewsBTC,
UToday,
Bitcoinist,
Coinpedia,
Cryptonomist,
CryptoNewsReview,
CCData,
Cryptoknowmics,
CCN,
FinanceMagnates,
ETHNewsDotCom,
CryptoVest,
CryptoInsider,
HuobiBlog,
CoinSpeaker,
CoinJoker,
NintyNineBitcoins,
Cointelligence,
OKXInsights,
CryptoCoreMedia,
Bitcoinerx,
AMBCrypto,
Coinpaprika,
LiveBitcoinNews,
CryptoCompare,
BitDegree,
TheCoinRepublic,
Chaindd,
Chaintimes,
TheCoinRise,
CryptoNewsZ,
YahooFinanceBitcoin,
VauldInsights,
ZyCrypto,
KrakenBlog,
Coincu,
DailyCoin,
TrustNodes,
Coinnounce,
CoinEdition,
BitcoinSistemi,
TheNewsCrypto,
ForbesDigitalAssets,
Cryptonews,
TimesNext,
EthereumWorldNews,
CryptoCoinDotNews,
BTCPulse,
BloombergCrypto,
CoinOtag,
CryptoDotNews,
Chainwire,
CryptoIntelligence,
Coinpaper,
BitfinexBlog,
TheCryptoBasic,
NFTDotNews,
Blokt,
BitcoinWorld,
CryptoDaily,
TimesTabloid,
CoinTurkNews,
Invezz,
SeekingAlpha,
Finbold,
FinancialTimesCrypto,
Cryptopolitan,
NullTx,
TipRanks,
TheDefiant,
}Expand description
Get articles from specific sources based on their keys. If left empty it will just return news from ACTIVE sources for the selected language, if you want to get inactive sources as well, please pass them in alongside the active ones in this array.
Variants
CoinDesk
CoinTelegraph
BitcoinMagazine
CryptoGlobe
CoinGape
Blockworks
TheDailyHodl
CryptoSlate
CryptoPotato
Decrypt
CryptoBriefing
TheBlock
BitcoinDotCom
NewsBTC
UToday
Bitcoinist
Coinpedia
Cryptonomist
CryptoNewsReview
CCData
Cryptoknowmics
CCN
FinanceMagnates
ETHNewsDotCom
CryptoVest
CryptoInsider
HuobiBlog
CoinSpeaker
CoinJoker
NintyNineBitcoins
Cointelligence
OKXInsights
CryptoCoreMedia
Bitcoinerx
AMBCrypto
Coinpaprika
LiveBitcoinNews
CryptoCompare
BitDegree
TheCoinRepublic
Chaindd
Chaintimes
TheCoinRise
CryptoNewsZ
YahooFinanceBitcoin
VauldInsights
ZyCrypto
KrakenBlog
Coincu
DailyCoin
TrustNodes
Coinnounce
CoinEdition
BitcoinSistemi
TheNewsCrypto
ForbesDigitalAssets
Cryptonews
TimesNext
EthereumWorldNews
CryptoCoinDotNews
BTCPulse
BloombergCrypto
CoinOtag
CryptoDotNews
Chainwire
CryptoIntelligence
Coinpaper
BitfinexBlog
TheCryptoBasic
NFTDotNews
Blokt
BitcoinWorld
CryptoDaily
TimesTabloid
CoinTurkNews
Invezz
SeekingAlpha
Finbold
FinancialTimesCrypto
Cryptopolitan
NullTx
TipRanks
TheDefiant