pub struct NewsCategory {
pub type_: String,
pub id: i32,
pub name: String,
pub filter: Option<CategoryFilter>,
pub status: String,
pub created_on: i64,
pub updated_on: Option<i64>,
}Expand description
News: Categories
Fields
type_: StringType of the message.
id: i32The unique identifier for the news category entry.
name: StringThe name of the news category.
filter: Option<CategoryFilter>The filters for the news category.
status: StringThe status for the News category entry. Allowed values: ACTIVE, INACTIVE.
created_on: i64News category internal creation unix ts in our system
updated_on: Option<i64>News category internal last updated unix ts in our system.