Module on_chain_core

Module on_chain_core 

Structs

ChainAssetSummary
OCCoreAssetByAddress
On-Chain Core: Asset by Address
OCCoreAssetByChain
On-Chain Core: Assets Summary By Chain
OCCoreContactDetails
Associated contact addresses for the team members, employees or affiliated contacts.
OCCoreDocumentURLs
Documents that might be relevant to the asset, they should all be .PDFs.
OCCoreETHBlock
ON-Chain Core: ETH Blocks
OCCoreETHMetadata
OCCoreETHTrace
OCCoreETHTransaction
OCCoreETHTransactionAccessList
This causes a transaction to warm (i.e. pre-cache) another addresses state and the specified storage keys, Available on EIP-2930 transactions.
OCCoreETHTransactionBlob
The current transaction blobs, null when there are no blobs attached to the transaction.
OCCoreETHTransactionLog
The chronological records of all activities such as transaction executions, contract interactions, errors, and changes that occur within a blockchain network.
OCCoreETHUncle
OCCoreETHWithdrawal
OCCorePriceConversionAsset
Denotes the convesion asset ID, SYMBOL and ASSET_TYPE.
OCCoreProjectLeader
Individuals that contains founders, whitepaper authors, investors, resechers, and other important people related to a project.
OCCoreReservesBreakdown
A detailed breakdown of reserves backing a stablecoin asset, covering various categories such as cash, cryptocurrency, bonds, and other investments for transparency.
OCCoreSecurityMetric
OCCoreSupply
On-Chain Core: Historical Supply Day
OCCoreSupportedPlatforms
OCCoreToplistRank
Indicates the asset’s position in our global asset ranking. There are multiple ranks, each is determined by at least one factor, such as asset launch date, market cap, trading volume, etc…
SupportedAsset