pub struct ChainAssetSummary {
pub type_: String,
pub id: i32,
pub symbol: String,
pub asset_type: String,
pub name: String,
pub logo_url: String,
pub launch_date: Option<i64>,
}Fields
type_: StringType of the message.
id: i32The unique identifier for the asset entry.
symbol: StringInternal mapped symbol for a specific asset.
asset_type: Stringhe asset class/type.
name: StringThe full name of the asset, e.g. Bitcoin.
logo_url: StringThe image that appears when you see this asset.
launch_date: Option<i64>The launch date of the asset is indicated as (yyyy-mm-dd). However, if the asset was initially established as a token before being integrated into a blockchain, the launch date is reset to the creation of the first block when the blockchain is launched for the token.