pub struct OptionsInstrumentMetadata {Show 25 fields
pub metadata_version: i32,
pub instrument_status: String,
pub firt_seen_on_polling_ts: i64,
pub last_seen_on_polling_ts: i64,
pub instrument: String,
pub instrument_mapping: OptionsInstrumentMapping,
pub instrument_external_data: String,
pub instrument_available_on_instruments_endpoint: bool,
pub index_id: String,
pub index_underlying: String,
pub quote_currency: String,
pub settlement_currency: String,
pub contract_currency: String,
pub contract_size: f64,
pub tick_size: f64,
pub contract_creation_ts: i64,
pub contract_expiration_ts: i64,
pub contract_expiration_year: i32,
pub contract_expiration_month_code: String,
pub strike_price: f64,
pub strike_currency: String,
pub option_type: String,
pub option_style: String,
pub base_currency: String,
pub min_trade_amount: f64,
}Fields
metadata_version: i32The version of metadata, used for version conversions/migrates.
instrument_status: StringThe status of the instrument, we only poll / stream / connect to the ACTIVE ones, for the RETIRED / IGNORED / EXPIRED / READY_FOR_DECOMMISSIONING means we no longer query/stream data.
firt_seen_on_polling_ts: i64This is the first time instrument was seen on instrumentListSourceType POLLING.
last_seen_on_polling_ts: i64This is the last time instrument was seen on instrumentListSourceType POLLING.
instrument: StringThe instrument ID as it is on the exchange with small modifications - we do not allow the following characters inside isntrument ids: ,/&?
instrument_mapping: OptionsInstrumentMappingThe current mapping information for this instrument
instrument_external_data: StringThe full data we get from the polling endpoint for this specific instrument. This is a JSON stringified object with different properties per exchange.
instrument_available_on_instruments_endpoint: boolThis flags the exchange instrument is currently available on instruments endpoint.
index_id: StringThe id of the index the contract is based on.
index_underlying: StringThe underlying instrument of the index.
quote_currency: StringThe instrument that the contract is priced in.
settlement_currency: StringThe currency used to calculate contract PnL. The settlement currency can be different from the index underlying or quote currencies.
contract_currency: StringThe denomination of the CONTRACT_SIZE.
contract_size: f64The contract size - how much of the contract currency does one contract contain.
tick_size: f64The minimum amount the price can move, denominated in QUOTE_CURRENCY.
contract_creation_ts: i64The contract creation timestamp we get for the specific derivative instrument.
contract_expiration_ts: i64The contract expiration timestamp we get for the specific derivative instrument. Not needed for PERPETUAL contract types.
contract_expiration_year: i32Year in which the contract expires.
contract_expiration_month_code: StringMonth in which the contract expires.
strike_price: f64The strike price.
strike_currency: StringThe denomination of the STRIKE_PRICE.
option_type: StringThe type of option contract.
option_style: StringThe style of option contract.
base_currency: StringThe base currency of the contract underlying index.
min_trade_amount: f64The minimum amount of contracts you can trade.