OverviewMktCapOHLCV

Struct OverviewMktCapOHLCV 

pub struct OverviewMktCapOHLCV {
    pub unit: String,
    pub timestamp: i64,
    pub type_: String,
    pub open: f64,
    pub high: f64,
    pub low: f64,
    pub close: f64,
    pub top_tier_volume: f64,
}
Overview: MktCap Historical OHLCV

Fields

unit: String

The unit of the message.

timestamp: i64

The timestamp in seconds of the beginning of the histo period. For minute it would be every minute at the beginning of the minute, for hour it would be the start of the hour and for daily it is 00:00 GMT.

type_: String

Type of the message, this is 886.

open: f64

The sum of assets circulating mkt caps (circulating supply * price quoted in USD) that meet the inclusion criteria closest to the start of the time period.

high: f64

The highest sum of assets circulating mkt caps (circulating supply * price quoted in USD) that meet the inclusion criteria during the time period.

low: f64

The lowest sum of assets circulating mkt caps (circulating supply * price quoted in USD) that meet the inclusion criteria during the time period.

close: f64

The sum of assets circulating mkt caps (circulating supply * price quoted in USD) that meet the inclusion criteria closest to the end of the time period.

top_tier_volume: f64

The sum of assets top-tier volumes (top-tier volume * price quoted in USD) that meet the inclusion criteria during the time period.