pub struct Instrument {
pub type_: String,
pub instrument_status: String,
pub instrument: String,
pub histo_shard: String,
pub mapped_instrument: String,
pub instrument_mapping: SpotInstrumentMapping,
pub has_trades_spot: bool,
pub first_trade_spot_timestamp: i64,
pub last_trade_spot_timestamp: i64,
pub total_trades_spot: i64,
}Fields
type_: StringType of the message.
instrument_status: StringStatus of the current instrument.
instrument: StringThe internal exchange defined instrument id.
histo_shard: StringOur internal shard for historical OHLCV+ (minute/hour/day) market data. Minute data is only held in the historical database for up to 3 weeks and we ship it to blob storage afterwards. The API utilizes multiple replicas of a single shard in a round-robin manner.
mapped_instrument: StringThe CoinDesk mapped instrument ID.
instrument_mapping: SpotInstrumentMappingThe current mapping information for this instrument.
has_trades_spot: boolA boolean field indicating whether the instrument has spot trades or not.
first_trade_spot_timestamp: i64The first spot defi trade timestamp.
last_trade_spot_timestamp: i64The last spot defi trade timestamp.
total_trades_spot: i64The total number of spot trades that this exchange has processed.