InstrumentStatus

Struct InstrumentStatus 

pub struct InstrumentStatus {
    pub active: i64,
    pub ignored: i64,
    pub retired: i64,
    pub expired: i64,
    pub undefined: Option<i64>,
}

Fields

active: i64

The total number of instruments currently available on the market, which are considered active. An active instrument is defined as an instrument from which we retrieve data and have either already mapped or are planning to map.

ignored: i64

The total number of instruments available on the market that are classified as ignored, meaning that we do not plan to map them. Ignored instruments are those from which we do retrieve data but do not have any intention to map.

retired: i64

The total number of instruments that are classified as retired, meaning that they are no longer actively traded on the market. These instruments have ceased trading, and as such, we do not retrieve data from them but we have mapped them already.

expired: i64

The total number of instruments that are classified as expired, meaning that they are mapped instruments that are no longer actively traded on the market. These expired instruments are typically futures or options instruments that have reached their expiration date and are no longer available for trading. While we have previously mapped these instruments, we do not retrieve any data from them since they are no longer actively traded.

undefined: Option<i64>