pub struct PreviousAssetSymbol {
pub symbol: Option<String>,
pub symbol_usage_start_date: Option<i64>,
pub symbol_usage_end_date: Option<i64>,
pub description: Option<String>,
}Fields
symbol: Option<String>A symbol this asset was previously associated with.
symbol_usage_start_date: Option<i64>Indicates the date this past symbol started being used.
symbol_usage_end_date: Option<i64>Indicates the date this past symbol stopped being used.
description: Option<String>A description for why this symbol existed or was changed.