pub struct SpecialAddress {
pub name: Option<String>,
pub blockchain: Option<String>,
pub address: Option<String>,
pub description: Option<String>,
}Fields
name: Option<String>The name of the address. Contract name or just the common name for this address.
blockchain: Option<String>The is linked to the asset representing a specific chain.
address: Option<String>The address of the smart contracts, external user accounts or other account.
description: Option<String>A description for the address.