APIEndpointTrait

Trait APIEndpointTrait 

pub trait APIEndpointTrait {
    // Required methods
    fn default_groups(&self) -> Option<Vec<Group>>;
    fn default_params(&self) -> Option<Vec<Param<'_>>>;
    fn url(&self, unit: &Unit) -> String;
}
Trait that defines all required methods for API endpoint URL construction (prior to adding non-default parameters). This is useful for defining custom API endpoints that are not included with the crate.

Required Methods

fn default_groups(&self) -> Option<Vec<Group>>

Returns a vector of default groups to apply to match the pre-defined schemas.

Note: If there are no default groups defined the None variant is returned.

fn default_params(&self) -> Option<Vec<Param<'_>>>

Returns a vector of default API endpoint parameters to apply to match the pre-defined schemas.

Note: If there are no default parameters defined the None variant is returned.

fn url(&self, unit: &Unit) -> String

Produces URL for a given API endpoint.

Input
  • unit: Unit of the interval between successive data points

Implementors