pub enum AssetLookupPriority {
Symbol,
Id,
URI,
}Expand description
Specifies the matching priority for the asset key provided in the asset parameter.
Description (CoinDesk Documentation)
This parameter specifies the matching priority for the asset key provided in the asset parameter. You can choose to match against the list of asset SYMBOLS, CoinDesk internal asset IDS, or asset URIs. Note that asset SYMBOLS and URIs may change due to rebrands or token switches, but the CoinDesk internal asset ID remains consistent.
Variants