pub enum Group {
Show 40 variants
Activity,
AssetTypeSpecificMetrics,
Basic,
Change,
Classification,
Contact,
Description,
DescriptionSummary,
General,
Id,
InstrumentSummary,
IntegrationFutures,
Internal,
Mapping,
MappingAdvanced,
Message,
Metadata,
Migration,
MktCap,
OHLC,
OHLCMessage,
OHLCSwap,
OHLCTrade,
OrphanTraces,
Price,
ResourceLinks,
SecurityMetrics,
SEO,
Source,
Status,
Supply,
SupplyAddresses,
SupportedPlatforms,
Swap,
ToplistRank,
Trade,
Transactions,
Uncles,
Volume,
Withdrawals,
}Expand description
Filtering groups.
Description (CoinDesk Documentation)
When requesting market metadata entries you can filter by specific groups of interest. To do so just pass the groups of interest into the URL as a comma separated list. If left empty it will get all data that your account is allowed to access.
Variants
Activity
AssetTypeSpecificMetrics
Basic
Change
Classification
Contact
Description
DescriptionSummary
General
Id
InstrumentSummary
IntegrationFutures
Internal
Mapping
MappingAdvanced
Message
Metadata
Migration
MktCap
OHLC
OHLCMessage
OHLCSwap
OHLCTrade
OrphanTraces
Price
ResourceLinks
SecurityMetrics
SEO
Status
Supply
SupplyAddresses
SupportedPlatforms
Swap
ToplistRank
Trade
Transactions
Uncles
Volume
Withdrawals