pub enum Param<'a> {
Show 25 variants
Symbol {
v: &'a str,
},
Instrument {
v: &'a str,
},
Instruments {
v: &'a Vec<String>,
},
ChainAsset {
v: &'a str,
},
Asset {
v: &'a str,
},
Assets {
v: Vec<String>,
},
ToTs {
v: Option<i64>,
},
ToTimestamp {
v: Option<i64>,
},
Limit {
v: Option<usize>,
},
Market {
v: String,
},
Markets {
v: Vec<String>,
},
InstrumentStatus {
v: SpotInstrumentStatus,
},
OCCoreBlockNumber {
v: i64,
},
OCCoreAddress {
v: &'a str,
},
OCCoreQuoteAsset {
v: &'a str,
},
NewsLanguage {
v: NewsLang,
},
NewsSourceID {
v: NewsSourceID,
},
NewsCategories {
v: Option<Vec<String>>,
},
NewsExcludeCategories {
v: Option<Vec<String>>,
},
NewsSourceType {
v: NewsSourceType,
},
NewsStatus {
v: NewsStatus,
},
Groups {
v: Option<Vec<Group>>,
},
ApplyMapping {
v: bool,
},
AssetLookupPriority {
v: AssetLookupPriority,
},
QuoteAsset {
v: &'a str,
},
}Expand description
All possible parameter types for the REST API request.
Variants
Symbol
Asset symbol
Instrument
Instrument symbol
Instruments
List of instrument symbols
ChainAsset
Chain asset symbol
Asset
Asset symbol
Assets
Assets’ symbols
ToTs
Final timestamp up to which the data will be extracted
ToTimestamp
Final timestamp up to which the data will be extracted
Limit
Maximum number of datapoints per API endpoint call
Market
Market name
Markets
Markets’ names
InstrumentStatus
Status of the instrument (e.g., ACTIVE, EXPIRED)
Fields
OCCoreBlockNumber
Block number on the blockchain
OCCoreAddress
Blockchain address
OCCoreQuoteAsset
Asset to quote data in
NewsLanguage
Language of the news
NewsSourceID
Source ID of the news stream
Fields
NewsCategories
List of news categories
NewsExcludeCategories
List of news categories to exclude
NewsSourceType
Type of news stream
Fields
NewsStatus
Status of the news stream (e.g., ACTIVE, INACTIVE)
Fields
v: NewsStatusGroups
Filtering groups
ApplyMapping
Determines if provided instrument values are converted according to internal mappings.
AssetLookupPriority
Specifies the matching priority for the asset key provided in the asset parameter.
Fields
QuoteAsset
Specify the digital asset for the quote values by providing either the CoinDesk internal asset ID, its unique SYMBOL, or the CoinDesk recommened URI.