pub async fn call_api_endpoint<'a, R: DeserializeOwned>(
api_key: &str,
endpoint: APIEndpoint,
unit: Unit,
params: Vec<Param<'a>>,
additional_params: Option<String>,
) -> Result<R, Error>Expand description
Constructs a URL for API request, sends the request, and returns the deserialzied response.
Input
api_key: CoinDesk API keyendpoint: Enum that represents the CoinDesk API endpoint for function to send the request tounit: Unit for data to be binned by (e.g.,Day,Hour)params: List of parameters expected by the CoinDesk API endpointadditional_params: Additional parameters to add to the request